/*Copyright (C) 2009  Annette Bieniusa, Thomas Fuhrmann.

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package dstm;

/**
 * Timer for debugging and logging.
 * @author Annette Bieniusa
 */

public class NanoTimeCollector {

	private long time;
	private long duration;

	protected NanoTimeCollector() {
		duration = 0;
		time = 0;
	}

	/**. 
	 *  Starts the timer
	 */
	protected void start() {
		time = System.nanoTime();
	}

	/**
	 * Returns in the duration since timer start. Additionally, duration gets accumulated.
	 * @return duration since last timer start
	 */
	protected long stop() {
		time = System.nanoTime() - time;
		duration += time;
		return duration;
	}

	/**
	 * Resets the total duration.
	 */
	protected void reset() {
		duration = 0;
	}

	/**
	 * Returns the accumulated duration of all measured timer intervals since
	 * the creation of timer or the last timer reset.
	 * 
	 * @return accumulated duration of all measured timer intervals
	 */
	protected long getTotalDuration() {
		return duration;
	}

}
